/*
 * ============================================================================
 * (C) Copyright IBM Corporation 2007, 2009.  All Rights Reserved.
 * 
 * You may only copy, modify, and distribute these samples internally.
 * These samples have not been tested under all conditions and are provided
 * to you by IBM without obligation of support of any kind.
 *
 * IBM PROVIDES THESE SAMPLES "AS IS" SUBJECT TO ANY STATUTORY WARRANTIES THAT
 * CANNOT BE EXCLUDED. IBM MAKES NO WARRANTIES OR CONDITIONS, EITHER EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OR
 * CONDITIONS OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
 * NON-INFRINGEMENT REGARDING THESE SAMPLES OR TECHNICAL SUPPORT, IF ANY.
 * ============================================================================
 */

/*
 * An event-based connection that converts a Map to JSON format on the request
 * and from JSON to a Map on the response.
 */

def onSimpleMap2JSONRequest() {
    // Is request body a Map?
    Object body = zget("/connection/request/body", null);
    if (body instanceof Map) {
        
        // Replace Map body with JSON encoded string
        zput("/connection/request/body", zero.json.Json.encode(body));
        
        // Set Content-Type header to the value from the handler configuration
        zput("/connection/request/headers/Content-Type",
              zget("/connection/configuration#contentType")
            );
        
    }
}

def onSimpleMap2JSONResponse() {
    // We'll recognize these MIME types as JSON
    List<String> recognizedTypes = Arrays.asList(
            "application/json",
            "application/javascript",
            "application/ecmascript",
            "application/x-javascript",
            "text/javascript",
            "text/ecmascript",
            "text/json",
            "text/x-json"
        );
    
    // Look for content type header
    String contentType = zget("/connection/response/headers/Content-Type#0", null);
    String mimeType = contentType.split(";")[0].trim();
    
    // Is MIME type recognised as JSON?
    if (recognizedTypes.contains(mimeType)) {
        
        // Decode JSON string to a map
        Object body = zget("/connection/response/body", null);
        String jsonString = zero.core.connection.utils.DataUtilities.convertToString(body, "UTF-8");
        zput("/connection/response/body", zero.json.Json.decode(jsonString));
        
    }
}

