/*
 * ============================================================================
 * (C) Copyright IBM Corporation 2007, 2008.  All Rights Reserved.
 * 
 * You may only copy, modify, and distribute these samples internally.
 * These samples have not been tested under all conditions and are provided
 * to you by IBM without obligation of support of any kind.
 *
 * IBM PROVIDES THESE SAMPLES "AS IS" SUBJECT TO ANY STATUTORY WARRANTIES THAT
 * CANNOT BE EXCLUDED. IBM MAKES NO WARRANTIES OR CONDITIONS, EITHER EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OR
 * CONDITIONS OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
 * NON-INFRINGEMENT REGARDING THESE SAMPLES OR TECHNICAL SUPPORT, IF ANY.
 * ============================================================================
 */
 
package email;

import zero.core.connection.Connection;
import zero.core.connection.EmailConnection;

/**
 * This sample gives an example of sending a HTML based e-mail using the EmailConnection API.
 * The e-mail will contain an inline image and an attached image.
 */
def onPOST() {
    
    def ret = "EmailConnection invocation successful. E-mail has been sent to " + request.params.to[];
    
    try {
        // Get the address to send the e-mail to. It should be posted to this script from the
        // Connection API Samples web page.
        def to = request.params.to[];
        if (to == null || to.equals("")) {
            ret = "Cannot invoke EmailConnection sample. No e-mail recipient specified";
        } else {
            def from = "email.sample@projectzero.org";
            def subject = "Greetings from the project zero e-mail sample";
            
            // Create the html for the body of the e-mail
            def message = """
                <html><body style="font-family:arial">
                <p><b>Greetings from the Project Zero EmailConnection API Sample</b></p>
                <p>This paragraph has an inline image ... <img src="inline.jpeg"> ... which is nice.</p>
                <p>There should be also be a <b>zero.jpeg</b> image attached to this email.</p>
                </body></html>
                """;
            
            // Create a new EmailConnection targetted at the e-mail address we wish to send the e-mail to
            def email = new EmailConnection(to);
            
            // Configure who the e-mail is from and the e-mail subject
            email.setFromAddress(from);
            email.setSubject(subject);
            
            // Set the html message as the content of the e-mail making sure to indicate the content type
            // in order for the message to be correctly displayed in the recipient's e-mail client.
            email.setContent(message, "text/html;charset=\"UTF-8\"");
            
            // Add an inline image, referenced in the html
            email.addInlineContent(Connection.doGET("file:///~/public/images/zero.jpeg").getResponseBody(), "image/jpeg", "inline.jpeg");
            
            // Add another image, this time as an attachment to the e-mail
            email.addAttachment(Connection.doGET("file:///~/public/images/ZeroGraphic.jpeg").getResponseBody(), "image/jpeg", "zero.jpeg");
            
            // Send the e-mail
            email.send();
        }
    } catch (Exception e) {
        ret = "EmailConnection invocation failed with exception " + e;
    }
    
    def html = invokeMethod("helper.groovy", "getResponseHTML", ret);
    println(html);
}