/*
 * ============================================================================
 * (C) Copyright IBM Corporation 2007, 2008.  All Rights Reserved.
 * 
 * You may only copy, modify, and distribute these samples internally.
 * These samples have not been tested under all conditions and are provided
 * to you by IBM without obligation of support of any kind.
 *
 * IBM PROVIDES THESE SAMPLES "AS IS" SUBJECT TO ANY STATUTORY WARRANTIES THAT
 * CANNOT BE EXCLUDED. IBM MAKES NO WARRANTIES OR CONDITIONS, EITHER EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OR
 * CONDITIONS OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
 * NON-INFRINGEMENT REGARDING THESE SAMPLES OR TECHNICAL SUPPORT, IF ANY.
 * ============================================================================
 */
 
package file;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import zero.core.connection.Connection;

/**
 * This sample gives an example of reading data from a file using the Connection API.
 * The file used in this sample contains simple text and is read using the streaming
 * capability of the Connection API.
 */
def onPOST() {
    def ret = "File GET invocation successful";
    
    try {
        // Create a connection targetted at the file we wich to read
        def conn = new Connection("file:///~/samplefiles/get.txt"); 
                        
        // Indicate that we wish to GET the data from the file
        conn.setOperation(Connection.Operation.GET);
        
        // Indicate the content type of the text in the file in order that the correct
        // conversion to bytes occurs.
        def contentType = "text/plain; charset=UTF-8";
        conn.addRequestHeader("Content-Type", contentType);
        
        // Call send to start the file read operation.
        def resp = conn.send();
        
        // Get an InputStream to allow us to stream in the contents of the file
        def inStream = resp.getResponseBodyInputStream("UTF-8");
        
        // Produce html from the file contents, to display on the web page
        def reader = new BufferedReader(new InputStreamReader(inStream, "UTF-8"));
        def sb = new StringBuilder();
        def line = reader.readLine();
        while (line != null) {
            sb.append(line);
            sb.append("<br>");
            line = reader.readLine();
        }
        ret = ret + ", file content was:<p><b>" + sb.toString() + "</b></p>";
    } catch (Exception e) {
        ret = "File GET invocation failed with exception " + e;
    }
    
    def html = invokeMethod("helper.groovy", "getResponseHTML", ret);
    println(html);
}