/*
 * ============================================================================
 * (C) Copyright IBM Corporation 2007, 2008.  All Rights Reserved.
 * 
 * You may only copy, modify, and distribute these samples internally.
 * These samples have not been tested under all conditions and are provided
 * to you by IBM without obligation of support of any kind.
 *
 * IBM PROVIDES THESE SAMPLES "AS IS" SUBJECT TO ANY STATUTORY WARRANTIES THAT
 * CANNOT BE EXCLUDED. IBM MAKES NO WARRANTIES OR CONDITIONS, EITHER EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OR
 * CONDITIONS OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
 * NON-INFRINGEMENT REGARDING THESE SAMPLES OR TECHNICAL SUPPORT, IF ANY.
 * ============================================================================
 */
 
package file;

import java.io.OutputStreamWriter;

import zero.core.connection.Connection;

/**
 * This sample gives an example of writing data to a file using the Connection API.
 * The file created by this sample is a simple text file and is written to using the streaming
 * capability of the Connection API.
 */
def onPOST() {
    def ret = "File PUT invocation successful";
    
    try {
        def filename = "written.txt";        

        // Create a new Connection targetted at the name of the file we wish to write.
        def conn = new Connection("file:///~/samplefiles/" + filename);
        
        // We will create the file and therefore use a PUT operation
        conn.setOperation(Connection.Operation.PUT);
        
        // Indicate the content type, in particular the charset of the text to be written
        // to the file.
        def contentType = "text/plain; charset=UTF-8";    
        conn.addRequestHeader("Content-Type", contentType);                    
        
        // Get the text to write to the file. It should be posted to this script from the
        // Connection API Samples web page.
        def message = request.params.message[0];
        
        // Get an OutputStreamWriter to use to write the text
        def writer = new OutputStreamWriter(conn.getRequestBodyOutputStream(), "UTF-8");
        writer.write(message);            
        writer.close();
        
        // Call send to write the data to the file.
        def resp = conn.send();
    } catch (Exception e) {
        ret = "File PUT invocation failed with exception " + e;
    }
    
    def html = invokeMethod("helper.groovy", "getResponseHTML", ret);
    println(html);
}