/*
 * ============================================================================
 * (C) Copyright IBM Corporation 2007, 2008.  All Rights Reserved.
 * 
 * You may only copy, modify, and distribute these samples internally.
 * These samples have not been tested under all conditions and are provided
 * to you by IBM without obligation of support of any kind.
 *
 * IBM PROVIDES THESE SAMPLES "AS IS" SUBJECT TO ANY STATUTORY WARRANTIES THAT
 * CANNOT BE EXCLUDED. IBM MAKES NO WARRANTIES OR CONDITIONS, EITHER EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OR
 * CONDITIONS OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
 * NON-INFRINGEMENT REGARDING THESE SAMPLES OR TECHNICAL SUPPORT, IF ANY.
 * ============================================================================
 */

package http;

import java.util.HashMap;

import zero.core.connection.Connection;
import zero.json.Json;

/**
 * This sample gives an example of making a simple HTTP request using the Connection API.
 * The data sent and received in the HTTP request and response will be in JSON format.
 */
def onPOST() {
    def ret = "HTTP (no handler) invocation successful";
    
    try {
        def map = new HashMap();
        map.put("name", "Fred");
        map.put("age", 35);
        map.put("membershipLevel", "gold");
        
        // Produce JSON formatted text from the map
        String json = Json.encode(map);
        
        // Create a new Connection targetted at the http address we wish to post data to.
        def conn = new Connection("http://localhost:8080/http/prime/dummy.groovy");
        
        // We are POSTing the data
        conn.setOperation(Connection.Operation.POST);
        
        // Indicate that we are sending JSON formatted text
        conn.addRequestHeader("Content-Type", "text/json; charset=UTF-8");            
        
        // Set the text to send
        conn.setRequestBody(json);
        
        // Get the response from the http service. Calling send causes the request to
        // be sent and returns the object from which the response can be obtained.
        def resp = conn.send();
        
        // Get the response as a String and then JSON decode it into a map
        def str = resp.getResponseBodyAsString();
        def respMap = Json.decode(str);
        
        ret = ret + ". Message from dummy service was <b>" + respMap.message + "</b>";
        
    } catch (Exception e) {
        ret = "HTTP (no handler) invocation failed with exception " + e;
    }
    
    def html = invokeMethod("helper.groovy", "getResponseHTML", ret);
    println(html);
}