/*
 * ============================================================================
 * (C) Copyright IBM Corporation 2007, 2008.  All Rights Reserved.
 * 
 * You may only copy, modify, and distribute these samples internally.
 * These samples have not been tested under all conditions and are provided
 * to you by IBM without obligation of support of any kind.
 *
 * IBM PROVIDES THESE SAMPLES "AS IS" SUBJECT TO ANY STATUTORY WARRANTIES THAT
 * CANNOT BE EXCLUDED. IBM MAKES NO WARRANTIES OR CONDITIONS, EITHER EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OR
 * CONDITIONS OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
 * NON-INFRINGEMENT REGARDING THESE SAMPLES OR TECHNICAL SUPPORT, IF ANY.
 * ============================================================================
 */

package http;

import java.util.HashMap;

import zero.core.connection.Connection;
import zero.json.Json;

/**
 * This sample gives an example of making a HTTP request using the Connection API.
 * Like the simple HTTP POST example, the data sent and received in the HTTP request 
 * and response will be in JSON format. However, in this example, we will make use of
 * a Connection Handler tpo carry out the conversion between JSON and Map. This
 * allows the caller to work exclusively with Maps and not be concerned with the
 * formatting of the request and response on the wire.
 */
def onPOST() {
    def ret = "HTTP (with handler) invocation successful";
    
    try {
        // Create a map of data to send
        def map = new HashMap();
        map.put("name", "Fred");
        map.put("age", 35);
        map.put("membershipLevel", "gold");
        
        // Create a new Connection targetted at the http address we wish to post data to.
        def conn = new Connection("http://localhost:8080/http/alt/dummyAlt.groovy");       
        
        // We wish to POST data
        conn.setOperation(Connection.Operation.POST);
        
        // Set the data to send
        conn.setRequestBody(map);
        
        // Get the response from the http service. Calling send causes the request to
        // be sent and returns the object from which the response can be obtained.
        def resp = conn.send();  
        
        // Get the data returned. The use of the handler will mean that the data will be
        // a Map.
        def respMap = resp.getResponseBody();        
        ret = ret + ". Message from dummy service was <b>" + respMap.message + "</b>";
        
    } catch (Exception e) {
        ret = "HTTP (with handler) invocation failed with exception " + e;
    }
    
    def html = invokeMethod("helper.groovy", "getResponseHTML", ret);
    println(html);
}